// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KHTML_VERSION_H
#define KHTML_VERSION_H

#define KHTML_VERSION_STRING "5.103.0"
#define KHTML_VERSION_MAJOR 5
#define KHTML_VERSION_MINOR 103
#define KHTML_VERSION_PATCH 0
#define KHTML_VERSION ((5<<16)|(103<<8)|(0))

#endif
